@@ -6,15 +6,20 @@ from compressio.diagnostics import (
     savings_report,
     storage_size,
 )
-from compressio.type_compressor import BaseTypeCompressor, DefaultCompressor
-from compressio.typing import pdT
+from compressio.type_compressor import (
+    BaseTypeCompressor,
+    DefaultCompressor,
+    SparseCompressor,
+)
 
 __all__ = [
     "Compress",
     "storage_size",
-    "TypeCompressor",
-    "StorageSize",
     "savings",
     "savings_report",
     "compress_report",
+    "BaseTypeCompressor",
+    "DefaultCompressor",
+    "SparseCompressor",
+    "type_compressions",
 ]
